==> openrqm-1.0.2.tar.gz: doc/ElementApi.md <==
# openrqm.api.ElementApi

## Load the API package
```dart
import 'package:openrqm/api.dart';
```

All URIs are relative to *https://virtserver.swaggerhub.com/benjaminSchilling33/OpenRQM/1.0.0*

Method | HTTP request | Description
------------- | ------------- | -------------
[**patchElement**](ElementApi.md#patchElement) | **PATCH** /element | Update an element
[**postElement**](ElementApi.md#postElement) | **POST** /element | Add an element
[**putElement**](ElementApi.md#putElement) | **PUT** /element | Update an element


# **patchElement**
> patchElement(element)

Update an element

### Example 
```dart
import 'package:openrqm/api.dart';

var api_instance = new ElementApi();
var element = new RQMElement(); // RQMElement | The element to update

try { 
    api_instance.patchElement(element);
} catch (e) {
    print("Exception when calling ElementApi->patchElement: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **element** | [**RQMElement**](RQMElement.md)| The element to update | [optional] 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **postElement**
> postElement(element)

Add an element

### Example 
```dart
import 'package:openrqm/api.dart';

var api_instance = new ElementApi();
var element = new RQMElement(); // RQMElement | The element to create

try { 
    api_instance.postElement(element);
} catch (e) {
    print("Exception when calling ElementApi->postElement: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **element** | [**RQMElement**](RQMElement.md)| The element to create | [optional] 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **putElement**
> putElement(element)

Update an element

### Example 
```dart
import 'package:openrqm/api.dart';

var api_instance = new ElementApi();
var element = new RQMElement(); // RQMElement | The element to update

try { 
    api_instance.putElement(element);
} catch (e) {
    print("Exception when calling ElementApi->putElement: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **element** | [**RQMElement**](RQMElement.md)| The element to update | [optional] 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> openrqm-1.0.3.tar.gz: doc/ElementApi.md <==
# openrqm.api.ElementApi

## Load the API package
```dart
import 'package:openrqm/api.dart';
```

All URIs are relative to *https://virtserver.swaggerhub.com/benjaminSchilling33/OpenRQM/1.0.0*

Method | HTTP request | Description
------------- | ------------- | -------------
[**patchElement**](ElementApi.md#patchElement) | **PATCH** /element | Update an element
[**postElement**](ElementApi.md#postElement) | **POST** /element | Add an element
[**putElement**](ElementApi.md#putElement) | **PUT** /element | Update an element


# **patchElement**
> patchElement(element)

Update an element

### Example 
```dart
import 'package:openrqm/api.dart';

var api_instance = ElementApi();
var element = RQMElement(); // RQMElement | The element to update

try { 
    api_instance.patchElement(element);
} catch (e) {
    print("Exception when calling ElementApi->patchElement: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **element** | [**RQMElement**](RQMElement.md)| The element to update | [optional] 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **postElement**
> postElement(element)

Add an element

### Example 
```dart
import 'package:openrqm/api.dart';

var api_instance = ElementApi();
var element = RQMElement(); // RQMElement | The element to create

try { 
    api_instance.postElement(element);
} catch (e) {
    print("Exception when calling ElementApi->postElement: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **element** | [**RQMElement**](RQMElement.md)| The element to create | [optional] 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **putElement**
> putElement(element)

Update an element

### Example 
```dart
import 'package:openrqm/api.dart';

var api_instance = ElementApi();
var element = RQMElement(); // RQMElement | The element to update

try { 
    api_instance.putElement(element);
} catch (e) {
    print("Exception when calling ElementApi->putElement: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **element** | [**RQMElement**](RQMElement.md)| The element to update | [optional] 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
